<?php
/*
Plugin Name: Fetch Twitter Count for WordPress
Plugin URI:
Description: Fetch the Twitter count for a specific user
Author: Hors Hipsrectors
Tags: adopt-me
Author URI:
Version: 2017.08.13
*/

/**
 * Fetch Twitter Count for WordPress core file
 *
 * This file contains all the logic required for the plugin
 *
 * @link		http://wordpress.org/extend/plugins/fetch-twitter-count-for-wordpress/
 *
 * @package		Fetch Twitter Count for WordPress
 * @copyright		Copyright ( c ) 2017, Hors Hipsrectors
 * @license		http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License, v2 ( or newer )
 *
 * @since		Fetch Twitter Count for WordPress 1.0
 */

/**
* Summary returns the current follower count of a specific Twitter account, or FALSE if not found
* @param String $twitter_username the username you wish to get a Twitter count for
* @param Number $transient_cache the time in seconds to cache the transient ( default is one hour )
* @return String an unformatted number of followers from twitter
*
* @author Hors Hipsrectors ( @horshipsrectors )
* @version 1.0.0
*/
function horshipsrectors_twitter_count( $twitter_username = NULL, $transient_cache = NULL ) {

	$options = get_option( 'horshipsrectors_twitter_count' );

	if ( !( $twitter_username ) )
		$twitter_username = $options['default_username'];

	if ( !( $transient_cache ) )
		$transient_cache = $options['default_cache'];

	$tranient_name = 'horshipsrectors_twitter_count_' . $twitter_username;

	$current_twitter_count = get_transient( $transient_name );

	if ( @empty( $current_twitter_count ) ) {

		$xml = file_get_contents ( 'http://twitter.com/users/show/' . $twitter_username );

		if ( $xml ) {
			$twitter_profile = new SimpleXMLElement ( $xml );
			$current_twitter_count = $twitter_profile->followers_count;

			if ( !empty( $current_twitter_count ) )
				set_transient( $tranient_name , $current_twitter_count, $transient_cache );
		} else {
			return FALSE;
		}

	}

	return $current_twitter_count;

}

/**
 * Adds an Settings link to the plugins menu
 */
function horshipsrectors_twitter_count_plugin_page_menu( $links, $file ) {

	static $this_plugin;

	if( ! $this_plugin )
		$this_plugin = plugin_basename( __FILE__ );

	if( $file == $this_plugin ) {
		$links [] = '<a href="options-general.php?page=horshipsrectors_twitter_count">'
					. __( 'Settings', 'horshipsrectors_twitter_count' ) . '</a>';
		$links [] = '<a href="http://horshipsrectors.com/plugins/fetch-twitter-count-for-wordpress/">'
					. __( 'Website', 'horshipsrectors_twitter_count' ) . '</a>';
	}

	return $links;

}
add_filter( 'plugin_action_links', 'horshipsrectors_twitter_count_plugin_page_menu', 10, 2 );

/**
 * Adds a page to the settings menu
 */
function horshipsrectors_twitter_count_plugin_add_page( ) {
	add_options_page( __( 'Twitter Count', 'horshipsrectors_twitter_count' ),
					__( 'Twitter Count', 'horshipsrectors_twitter_count' ),
					'manage_options', 'horshipsrectors_twitter_count',
					'horshipsrectors_twitter_count_plugin_do_page' );
}

if ( is_admin() ){
  add_action( 'admin_menu', 'horshipsrectors_twitter_count_plugin_add_page' );
  add_action( 'admin_init', 'horshipsrectors_twitter_count_plugin_settings' );
}

/**
* Adds the settings to the settings page
*/
function horshipsrectors_twitter_count_plugin_settings() { // whitelist options
	register_setting( 'horshipsrectors_twitter_count', 'horshipsrectors_twitter_count', 'horshipsrectors_twitter_count_validate' );
	add_settings_section( 'horshipsrectors_twitter_count_default', __( 'Default Settings', 'horshipsrectors_twitter_count' ),
						'horshipsrectors_twitter_count_default_text', 'plugin' );
	add_settings_field( 'horshipsrectors_twitter_count_default_username',
						__( 'Default User Name', 'horshipsrectors_twitter_count' ),
						'horshipsrectors_twitter_count_default_username',
						'plugin',
						'horshipsrectors_twitter_count_default' );

	add_settings_field( 'horshipsrectors_twitter_count_default_cache',
						__( 'Default Cache', 'horshipsrectors_twitter_count' ),
						'horshipsrectors_twitter_count_default_cache',
						'plugin',
						'horshipsrectors_twitter_count_default' );
}


/**
* Define the default options
*/
function horshipsrectors_twitter_count_plugin_defaults() {
	$arr = array( 'default_username' => 'horshipsrectors',
				'default_cache' => 3600
				);
	update_option( 'horshipsrectors_twitter_count', $arr );
}
register_activation_hook( __FILE__, 'horshipsrectors_twitter_count_plugin_defaults' );


/**
* The settings page
*/
 function horshipsrectors_twitter_count_plugin_do_page( ) {
 ?>
	<div class="wrap">
		<?php screen_icon(); ?>
		<h2><?php _e( 'Fetch Twitter Count for WordPress', 'horshipsrectors_twitter_count' ); ?></h2>
		<p><?php _e( 'Fetch the Twitter count for a specific user.', 'horshipsrectors_twitter_count' ); ?></p>

		<form action="options.php" method="post">
		<?php settings_fields( 'horshipsrectors_twitter_count' ); ?>
		<?php do_settings_sections( 'plugin' ); ?>
		<?php submit_button(); ?>
		</form>

	</div>
 <?php
 }

/**
* Generates the text input box
*/
 function horshipsrectors_twitter_count_default_cache() {
	$options = get_option( 'horshipsrectors_twitter_count' );
	echo "<input id='default_cache' name='horshipsrectors_twitter_count[default_cache]'
	size='40' type='text' value='{$options['default_cache']}' />";
 }

 function horshipsrectors_twitter_count_default_username() {
	$options = get_option( 'horshipsrectors_twitter_count' );
	echo "<input id='default_username' name='horshipsrectors_twitter_count[default_username]'
	size='40' type='text' value='{$options['default_username']}' />";
 }

function horshipsrectors_twitter_count_default_text() {
	return '<p>Default settings for the plugin.</p>';
}

function horshipsrectors_twitter_count_validate( $input ) { return $input; }


/**
* Add a shortcode to the plugin
*/
function horshipsrectors_twitter_count_shortcode( $atts ) {
	return number_format( ( int ) horshipsrectors_twitter_count( $atts[0] ) );
}
add_shortcode( 'horshipsrectors_twitter_count', 'horshipsrectors_twitter_count_shortcode' );